==> zio-aws-route53recoverycontrolconfig_2.12-5.17.153.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/CreateSafetyRuleResponse.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateSafetyRuleResponse(
    assertionRule: Option[
      zio.aws.route53recoverycontrolconfig.model.AssertionRule
    ] = None,
    gatingRule: Option[zio.aws.route53recoverycontrolconfig.model.GatingRule] =
      None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse = {
    import CreateSafetyRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
      .builder()
      .optionallyWith(assertionRule.map(value => value.buildAwsValue()))(
        _.assertionRule
      )
      .optionallyWith(gatingRule.map(value => value.buildAwsValue()))(
        _.gatingRule
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
      .wrap(buildAwsValue())
}
object CreateSafetyRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse =
      zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse(
        assertionRule.map(value => value.asEditable),
        gatingRule.map(value => value.asEditable)
      )
    def assertionRule: Option[
      zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly
    ]
    def gatingRule
        : Option[zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly]
    def getAssertionRule: ZIO[
      Any,
      AwsError,
      zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly
    ] = AwsError.unwrapOptionField("assertionRule", assertionRule)
    def getGatingRule: ZIO[
      Any,
      AwsError,
      zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly
    ] = AwsError.unwrapOptionField("gatingRule", gatingRule)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
  ) extends zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse.ReadOnly {
    override val assertionRule: Option[
      zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly
    ] = scala
      .Option(impl.assertionRule())
      .map(value =>
        zio.aws.route53recoverycontrolconfig.model.AssertionRule.wrap(value)
      )
    override val gatingRule: Option[
      zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly
    ] = scala
      .Option(impl.gatingRule())
      .map(value =>
        zio.aws.route53recoverycontrolconfig.model.GatingRule.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
  ): zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-route53recoverycontrolconfig_2.12-5.17.265.1-sources.jar: zio/aws/route53recoverycontrolconfig/model/CreateSafetyRuleResponse.scala <==
package zio.aws.route53recoverycontrolconfig.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateSafetyRuleResponse(
    assertionRule: Optional[
      zio.aws.route53recoverycontrolconfig.model.AssertionRule
    ] = Optional.Absent,
    gatingRule: Optional[
      zio.aws.route53recoverycontrolconfig.model.GatingRule
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse = {
    import CreateSafetyRuleResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
      .builder()
      .optionallyWith(assertionRule.map(value => value.buildAwsValue()))(
        _.assertionRule
      )
      .optionallyWith(gatingRule.map(value => value.buildAwsValue()))(
        _.gatingRule
      )
      .build()
  }
  def asReadOnly
      : zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse.ReadOnly =
    zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
      .wrap(buildAwsValue())
}
object CreateSafetyRuleResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse =
      zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse(
        assertionRule.map(value => value.asEditable),
        gatingRule.map(value => value.asEditable)
      )
    def assertionRule: Optional[
      zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly
    ]
    def gatingRule: Optional[
      zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly
    ]
    def getAssertionRule: ZIO[
      Any,
      AwsError,
      zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly
    ] = AwsError.unwrapOptionField("assertionRule", assertionRule)
    def getGatingRule: ZIO[
      Any,
      AwsError,
      zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly
    ] = AwsError.unwrapOptionField("gatingRule", gatingRule)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
  ) extends zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse.ReadOnly {
    override val assertionRule: Optional[
      zio.aws.route53recoverycontrolconfig.model.AssertionRule.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.assertionRule())
      .map(value =>
        zio.aws.route53recoverycontrolconfig.model.AssertionRule.wrap(value)
      )
    override val gatingRule: Optional[
      zio.aws.route53recoverycontrolconfig.model.GatingRule.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.gatingRule())
      .map(value =>
        zio.aws.route53recoverycontrolconfig.model.GatingRule.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.route53recoverycontrolconfig.model.CreateSafetyRuleResponse
  ): zio.aws.route53recoverycontrolconfig.model.CreateSafetyRuleResponse.ReadOnly =
    new Wrapper(impl)
}
